@@ -3,11 +3,11 @@ package SQLx::Lite;
 use 5.010;
 use DBI;
 
-use SQLx::Lite::DBH;
+use SQLx::Lite::Schema;
 use SQLx::Lite::ResultSet;
 use SQLx::Lite::Result;
 
-$SQLx::Lite::VERSION = '3.0.5_003';
+$SQLx::Lite::VERSION = '3.0.5_005';
 
 =head1 NAME
 
@@ -75,8 +75,8 @@ sub connect {
         return 0;
     };
 
-    my $dbh = { dbh => $dbh };
-    bless $dbh, 'SQLx::Lite::DBH';
+    my $dbhx = { dbh => $dbh };
+    bless $dbhx, 'SQLx::Lite::Schema';
 }
 
 =head1 AUTHOR
